==> google-cloud-dialogflow-2.0.0.tar.gz: google-cloud-dialogflow-2.0.0/google/cloud/dialogflow_v2beta1/services/intents/pagers.py <==
# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from typing import Any, AsyncIterable, Awaitable, Callable, Iterable, Sequence, Tuple

from google.cloud.dialogflow_v2beta1.types import intent


class ListIntentsPager:
    """A pager for iterating through ``list_intents`` requests.

    This class thinly wraps an initial
    :class:`~.intent.ListIntentsResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``intents`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListIntents`` requests and continue to iterate
    through the ``intents`` field on the
    corresponding responses.

    All the usual :class:`~.intent.ListIntentsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., intent.ListIntentsResponse],
        request: intent.ListIntentsRequest,
        response: intent.ListIntentsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (:class:`~.intent.ListIntentsRequest`):
                The initial request object.
            response (:class:`~.intent.ListIntentsResponse`):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = intent.ListIntentsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterable[intent.ListIntentsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterable[intent.Intent]:
        for page in self.pages:
            yield from page.intents

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListIntentsAsyncPager:
    """A pager for iterating through ``list_intents`` requests.

    This class thinly wraps an initial
    :class:`~.intent.ListIntentsResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``intents`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListIntents`` requests and continue to iterate
    through the ``intents`` field on the
    corresponding responses.

    All the usual :class:`~.intent.ListIntentsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., Awaitable[intent.ListIntentsResponse]],
        request: intent.ListIntentsRequest,
        response: intent.ListIntentsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (:class:`~.intent.ListIntentsRequest`):
                The initial request object.
            response (:class:`~.intent.ListIntentsResponse`):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = intent.ListIntentsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterable[intent.ListIntentsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterable[intent.Intent]:
        async def async_generator():
            async for page in self.pages:
                for response in page.intents:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)

==> google-cloud-dialogflow-2.1.0.tar.gz: google-cloud-dialogflow-2.1.0/google/cloud/dialogflow_v2beta1/services/intents/pagers.py <==
# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from typing import (
    Any,
    AsyncIterable,
    Awaitable,
    Callable,
    Iterable,
    Sequence,
    Tuple,
    Optional,
)

from google.cloud.dialogflow_v2beta1.types import intent


class ListIntentsPager:
    """A pager for iterating through ``list_intents`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.dialogflow_v2beta1.types.ListIntentsResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``intents`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListIntents`` requests and continue to iterate
    through the ``intents`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.dialogflow_v2beta1.types.ListIntentsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., intent.ListIntentsResponse],
        request: intent.ListIntentsRequest,
        response: intent.ListIntentsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.dialogflow_v2beta1.types.ListIntentsRequest):
                The initial request object.
            response (google.cloud.dialogflow_v2beta1.types.ListIntentsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = intent.ListIntentsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterable[intent.ListIntentsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterable[intent.Intent]:
        for page in self.pages:
            yield from page.intents

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListIntentsAsyncPager:
    """A pager for iterating through ``list_intents`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.dialogflow_v2beta1.types.ListIntentsResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``intents`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListIntents`` requests and continue to iterate
    through the ``intents`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.dialogflow_v2beta1.types.ListIntentsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., Awaitable[intent.ListIntentsResponse]],
        request: intent.ListIntentsRequest,
        response: intent.ListIntentsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.dialogflow_v2beta1.types.ListIntentsRequest):
                The initial request object.
            response (google.cloud.dialogflow_v2beta1.types.ListIntentsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = intent.ListIntentsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterable[intent.ListIntentsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterable[intent.Intent]:
        async def async_generator():
            async for page in self.pages:
                for response in page.intents:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)
